package cmd

import (
	"github.com/carapace-sh/carapace"
	"github.com/spf13/cobra"
)

var overrideCmd = &cobra.Command{
	Use:   "override",
	Short: "Modify toolchain overrides for directories",
	Run:   func(cmd *cobra.Command, args []string) {},
}

func init() {
	carapace.Gen(overrideCmd).Standalone()

	overrideCmd.Flags().BoolP("help", "h", false, "Print help")
	rootCmd.AddCommand(overrideCmd)
}
